/**
 * OWASP CSRFTester
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * Copyright (c) 2007 - The OWASP Foundation
 * 
 * The CSRFTester is published by OWASP under the LGPL. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @created 2007
 */

package org.owasp.csrftester;

import javax.swing.table.*;
import java.io.*;
import java.util.regex.*;
import org.owasp.webscarab.util.Encoding;

/**
 *
 * @author jwilliams
 */
public class CSRFTesterModel extends DefaultTableModel {
    public static String DEFAULT_INCLUDE_PATTERN = ".*";
    public static String DEFAULT_EXCLUDE_PATTERN = ".*\\.(gif|jpg|png|css|ico|js|axd\\?.*|ico)$";
    public static String SEPARATOR = "\t";
    private boolean dirty = false;
    private Pattern include = Pattern.compile( DEFAULT_INCLUDE_PATTERN );
    private Pattern exclude = Pattern.compile( DEFAULT_EXCLUDE_PATTERN );
    private String linkText = null;
    
    public CSRFTesterModel() {
        super(
                new Object [][] {
        },
                new String [] {
            "Step", "Method", "URL", "Parameters", "Pause"
        }
        );
    }
    
    public void setIncludePattern( String pattern ) throws PatternSyntaxException {
        // FIXME: save this individually?
        //System.out.println( "SET INCLUDE: " + pattern );
        include = Pattern.compile( pattern );
    }
    
    public void setExcludePattern( String pattern ) throws PatternSyntaxException {
        // FIXME: save this individually?
        //System.out.println( "SET EXCLUDE: " + pattern );
        exclude = Pattern.compile( pattern );
    }
    
    public String getLinkText() {
    	return linkText;
    }
    
    public void setLinkText(String linkText) {
    	this.linkText = linkText;
    }
    
    public boolean saveNeeded() {
        return dirty;
    }
    
    public String getStepName( int row ) {
        return getValueAt( row, 0 ).toString();
    }
    
    public void setStepName( int row, String value ) {
        dirty = true;
        setValueAt( value, row, 0 );
    }
    
    public String getMethod( int row ) {
        return getValueAt( row, 1 ).toString();
    }
    
    public void setMethod( int row, String value ) {
        dirty = true;
        setValueAt( value, row, 1 );
    }
    
    public String getURL( int row ) {
        return getValueAt( row, 2 ).toString();
    }
    
    public void setURL( int row, String value ) {
        dirty = true;
        setValueAt( value, row, 2 );
    }
    
    public String getParameters( int row ) {
        return getValueAt( row, 3 ).toString();
    }
    
    public void setParameters( int row, String value ) {
        dirty = true;
        setValueAt( value, row, 3 );
    }
    
    public int getPause( int row ) {
        String str = getValueAt( row, 4 ).toString();
        int pause = Integer.parseInt( str );
        return pause;
    }
    
    public void setPause( int row, String value ) {
        dirty = true;
        setValueAt( value, row, 4 );
        this.fireTableDataChanged();
    }
    

    public void addHttpRequest( String stepName, String method, String url, String params, int pause ) {
        if ( include.matcher( url ).matches() && !exclude.matcher( url ).matches() ) {
            dirty = true;
            String[] data = new String[5];
            data[0] = stepName;
            data[1] = method;
            data[2] = Encoding.urlDecode( url ).replace('\"', '\'');
            data[3] = Encoding.urlDecode( params ).replace('\"', '\'');
            data[4] = ""+pause;
            this.addRow( data );
        }
    }
    
    public void clear() {
        dirty = true;
        while ( getRowCount() > 0 ) {
            removeRow( 0 );
        }
    }
    
    public void load( File f ) throws IOException {
        clear();
        BufferedReader r = new BufferedReader( new FileReader( f ) );
        String line = "";
        while ( ( line = r.readLine() ) != null ) {
            this.addRow( parse( line ) );
        }
        r.close();
        dirty = false;
    }
    
    private String[] parse( String line ) {
        String[] data = new String[5];
        String[] parts = line.split( SEPARATOR );
        data[0] = parts[0];
        data[1] = parts[1];
        data[2] = parts[2];
        data[3] = parts[3];
        data[4] = parts[4];
        return data;
    }
    
    public void save( File f ) throws IOException {
        /// FIXME: maybe B64 encode data to prevent possible though unlikely misparses
        BufferedWriter w = new BufferedWriter( new FileWriter( f ) );
        StringBuffer sb = new StringBuffer();
        for ( int i=0; i<this.getRowCount(); i++ ) {
            sb.delete( 0, sb.length() );
            sb.append( this.getValueAt( i, 0 ) + SEPARATOR );
            sb.append( this.getValueAt( i, 1 ) + SEPARATOR );
            sb.append( this.getValueAt( i, 2 ) + SEPARATOR );
            sb.append( this.getValueAt( i, 3 ) + SEPARATOR );
            sb.append( this.getValueAt( i, 4 ) );
            w.write( sb.toString() );
            w.newLine();
        }
        w.close();
        dirty = false;
    }
    
    /**
     * We need to make sure that the row exists before attempting to set
     * its value.
     * @param value
     * @param row
     * @param column
     */
    private void setValueAt(String value, int row, int column)
    {
    	int rowCount = this.getRowCount();
    	
    	if(rowCount >= row)
    	{
    		super.setValueAt(value, row, column);
    	}
    }
}
