/**
 * OWASP CSRFTester
 * 
 * This file is part of the Open Web Application Security Project (OWASP)
 * Copyright (c) 2007 - The OWASP Foundation
 * 
 * The CSRFTester is published by OWASP under the LGPL. You should read and accept the
 * LICENSE before you use, modify, and/or redistribute this software.
 * 
 * @author <a href="http://www.aspectsecurity.com">Aspect Security</a>
 * @created 2007
 */

package org.owasp.csrftester.report;

import java.io.IOException;
import java.io.File;
import org.owasp.csrftester.BrowserLaunch;
import org.owasp.csrftester.CSRFTesterModel;

/**
 *
 * @author jwilliams
 */
public final class FormsReport extends ReportAdapter
{
    protected FormsReport()
    {
    	
    }
    
    public String generateHtml(CSRFTesterModel model, File dir) throws IOException
    {
    	int formCount = getFormCount(model);
    	String formHtml = getFormHtml(model);
    	String content = getContent("/resources/FormsTemplate.html");
    	String pauseHtml = getPauseHtml(model);
    	
    	content = content.replace("<%PAUSES%>", pauseHtml);
    	content = content.replace("<%COUNT%>", String.valueOf(formCount));
    	content = content.replace("<%FORMS%>", formHtml);
    	writeFile(dir, "index.html", content);
    	return "file://" + dir.getPath() + "/index.html";
    }
    
    private int getFormCount(CSRFTesterModel model)
    {
    	return model.getRowCount();
    }
    
    private String getFormHtml(CSRFTesterModel model)
    {
    	StringBuffer sb = new StringBuffer();
    	int count = model.getRowCount();
    	
    	for(int i=0; i<count; i++)
    	{
    		sb.append("<form method=\"" + model.getMethod(i) + "\" name=\"form" + i + "\" action=\"" + model.getURL(i) + "\">\r\n");
    		sb.append(getParametersAsHtmlInput(model, i));
    		sb.append("</form>\r\n");
    	}
    	
    	return sb.toString();
    }
    
    private String getPauseHtml(CSRFTesterModel model)
    {
    	StringBuffer pauses = new StringBuffer();
        int count = model.getRowCount();
        
        for ( int i=0; i < count; i++ )
        {
            pauses.append( "\"" + model.getPause(i) + "\"" );
            
            if ( i != count-1 ) {
                pauses.append( "," );
            }
        }
        
        return pauses.toString();
    }
}